@@ -20,25 +20,28 @@ if TYPE_CHECKING:  # pragma: no cover
 # Classes: Private
 # ======================================================================================================================
 class _DefaultConfig(dict):  # type: ignore
+    """
+    The default Flask settings for all environments.
+
+    Args:
+        api_title: The title (name) of the API to display in the OpenAPI documentation.
+        api_version: The semantic version for the OpenAPI client.
+        openapi_client_name: The package name to use for generated OpenAPI clients.
+        kwargs: Additional settings to add to the configuration.
+
+    Raises:
+        RuntimeError: Attempted to override a protected setting or specified an additional setting that was not all
+            uppercase.
+    """
+
     def __init__(self, api_title: str, api_version: str, openapi_client_name: str, **kwargs: dict[str, Any]):
-        """The default Flask settings for all environments.
-
-        Args:
-            api_title: The title (name) of the API to display in the OpenAPI documentation.
-            api_version: The semantic version for the OpenAPI client.
-            openapi_client_name: The package name to use for generated OpenAPI clients.
-            kwargs: Additional settings to add to the configuration.
-
-        Raises:
-            RuntimeError: Attempted to override a protected setting or specified an additional setting that was not all
-                uppercase.
-        """
-
         # Settings are specific to this library
         ligand_default_settings: dict[str, Any] = {
             "SERVICE_PUBLIC_URL": os.getenv("SERVICE_PUBLIC_URL"),
             "SERVICE_PRIVATE_URL": os.getenv("SERVICE_PRIVATE_URL"),
-            "ALLOWED_ROLES": os.getenv("ALLOWED_ROLES", "").split(","),
+            "ALLOWED_ROLES": os.getenv("ALLOWED_ROLES").split(",")  # type: ignore
+            if os.getenv("ALLOWED_ROLES") is not None
+            else None,
         }
 
         db_default_settings: dict[str, Any] = {
@@ -50,8 +53,7 @@ class _DefaultConfig(dict):  # type: ignore
         }
 
         auth_default_settings: dict[str, Any] = {
-            "OIDC_ISSUER_URL": os.getenv("OIDC_ISSUER_URL"),
-            "OIDC_REALM": os.getenv("OIDC_REALM"),
+            "OIDC_DISCOVERY_URL": os.getenv("OIDC_DISCOVERY_URL"),
             "VERIFY_SSL_CERT": True,
             "JWT_TOKEN_LOCATION": "headers",
             "JWT_HEADER_NAME": "Authorization",
@@ -91,25 +93,41 @@ class _DefaultConfig(dict):  # type: ignore
             else:
                 raise RuntimeError(f"The setting name '{key}' must be uppercase!")
 
+        required_settings: dict[str, Any] = {
+            "SERVICE_PUBLIC_URL": self["SERVICE_PUBLIC_URL"],
+            "SERVICE_PRIVATE_URL": self["SERVICE_PRIVATE_URL"],
+            "ALLOWED_ROLES": self["ALLOWED_ROLES"],
+            "OIDC_DISCOVERY_URL": self["OIDC_DISCOVERY_URL"],
+            "SQLALCHEMY_DATABASE_URI": self["SQLALCHEMY_DATABASE_URI"],
+            "OPENAPI_GEN_SERVER_URL": self["OPENAPI_GEN_SERVER_URL"],
+        }
+
+        for key in required_settings:
+            if required_settings[key] is None:
+                raise RuntimeError(
+                    f"The '{key}' environment variable must be set when running in this Flask environment!"
+                )
+
 
 # ======================================================================================================================
 # Classes: Public
 # ======================================================================================================================
 class ProdConfig(_DefaultConfig):
+    """
+    Configuration for production environments.
+
+    Args:
+        api_title: The title (name) of the API to display in the OpenAPI documentation.
+        api_version: The semantic version for the OpenAPI client.
+        openapi_client_name: The package name to use for generated OpenAPI clients.
+        kwargs: Additional settings to add to the configuration.
+
+    Raises:
+        RuntimeError: Attempted to override a protected setting or specified an additional setting that was not all
+            uppercase.
+    """
+
     def __init__(self, api_title: str, api_version: str, openapi_client_name: str, **kwargs: dict[str, Any]):
-        """Configuration for production environments.
-
-        Args:
-            api_title: The title (name) of the API to display in the OpenAPI documentation.
-            api_version: The semantic version for the OpenAPI client.
-            openapi_client_name: The package name to use for generated OpenAPI clients.
-            kwargs: Additional settings to add to the configuration.
-
-        Raises:
-            RuntimeError: Attempted to override a protected setting or specified an additional setting that was not all
-                uppercase.
-        """
-
         prod_settings: dict[str, Any] = {
             "JWT_ALGORITHM": "RS256",
             "JWT_DECODE_AUDIENCE": os.getenv("JWT_DECODE_AUDIENCE"),
@@ -121,20 +139,21 @@ class ProdConfig(_DefaultConfig):
 
 
 class StagingConfig(ProdConfig):
+    """
+    Configuration for development/staging environments.
+
+    Args:
+        api_title: The title (name) of the API to display in the OpenAPI documentation.
+        api_version: The semantic version for the OpenAPI client.
+        openapi_client_name: The package name to use for generated OpenAPI clients.
+        kwargs: Additional settings to add to the configuration.
+
+    Raises:
+        RuntimeError: Attempted to override a protected setting or specified an additional setting that was not all
+            uppercase.
+    """
+
     def __init__(self, api_title: str, api_version: str, openapi_client_name: str, **kwargs: dict[str, Any]):
-        """Configuration for development/staging environments.
-
-        Args:
-            api_title: The title (name) of the API to display in the OpenAPI documentation.
-            api_version: The semantic version for the OpenAPI client.
-            openapi_client_name: The package name to use for generated OpenAPI clients.
-            kwargs: Additional settings to add to the configuration.
-
-        Raises:
-            RuntimeError: Attempted to override a protected setting or specified an additional setting that was not all
-                uppercase.
-        """
-
         dev_settings: dict[str, Any] = {"VERIFY_SSL_CERT": False}
 
         combined_settings = {**dev_settings, **kwargs}
@@ -143,20 +162,21 @@ class StagingConfig(ProdConfig):
 
 
 class FlaskLocalConfig(StagingConfig):
+    """
+    Configuration used for running a local Flask server.
+
+    Args:
+        api_title: The title (name) of the API to display in the OpenAPI documentation.
+        api_version: The semantic version for the OpenAPI client.
+        openapi_client_name: The package name to use for generated OpenAPI clients.
+        kwargs: Additional settings to add to the configuration.
+
+    Raises:
+        RuntimeError: Attempted to override a protected setting or specified an additional setting that was not all
+            uppercase.
+    """
+
     def __init__(self, api_title: str, api_version: str, openapi_client_name: str, **kwargs: dict[str, Any]):
-        """Configuration used for running a local Flask server.
-
-        Args:
-            api_title: The title (name) of the API to display in the OpenAPI documentation.
-            api_version: The semantic version for the OpenAPI client.
-            openapi_client_name: The package name to use for generated OpenAPI clients.
-            kwargs: Additional settings to add to the configuration.
-
-        Raises:
-            RuntimeError: Attempted to override a protected setting or specified an additional setting that was not all
-                uppercase.
-        """
-
         # noinspection HttpUrlsUsage
         flask_local_settings: dict[str, Any] = {
             "SERVICE_PUBLIC_URL": os.getenv("SERVICE_PUBLIC_URL", "http://localhost:5000"),
@@ -177,26 +197,26 @@ class FlaskLocalConfig(StagingConfig):
 
 
 class TestingConfig(_DefaultConfig):
+    """
+    Configuration used for unit testing.
+
+    Args:
+        api_title: The title (name) of the API to display in the OpenAPI documentation.
+        api_version: The semantic version for the OpenAPI client.
+        openapi_client_name: The package name to use for generated OpenAPI clients.
+        kwargs: Additional settings to add to the configuration.
+
+    Raises:
+        RuntimeError: Attempted to override a protected setting or specified an additional setting that was not all
+            uppercase.
+    """
+
     def __init__(self, api_title: str, api_version: str, openapi_client_name: str, **kwargs: dict[str, Any]):
-        """Configuration used for unit testing.
-
-        Args:
-            api_title: The title (name) of the API to display in the OpenAPI documentation.
-            api_version: The semantic version for the OpenAPI client.
-            openapi_client_name: The package name to use for generated OpenAPI clients.
-            kwargs: Additional settings to add to the configuration.
-
-        Raises:
-            RuntimeError: Attempted to override a protected setting or specified an additional setting that was not all
-                uppercase.
-        """
-
         testing_settings: dict[str, Any] = {
             "SERVICE_PUBLIC_URL": os.getenv("SERVICE_PUBLIC_URL", "http://public.url"),
             "SERVICE_PRIVATE_URL": os.getenv("SERVICE_PRIVATE_URL", "http://private.url"),
             "ALLOWED_ROLES": os.getenv("ALLOWED_ROLES", "user,admin").split(","),
-            "OIDC_ISSUER_URL": "TESTING",
-            "OIDC_REALM": "TESTING",
+            "OIDC_DISCOVERY_URL": "TESTING",
             "VERIFY_SSL_CERT": False,
             "JWT_ACCESS_TOKEN_EXPIRES": 300,
             "JWT_SECRET_KEY": "super-duper-secret",
@@ -220,6 +240,7 @@ ENVIRONMENTS = {
     "stage": StagingConfig,
     "local": FlaskLocalConfig,
     "testing": TestingConfig,
+    "cli": ProdConfig,
 }
 
 
@@ -239,10 +260,16 @@ def flask_environment_configurator(
     Args:
         app: The root Flask app to configure with the given extension.
         environment: The target environment to create a Flask configuration object for. Available environments:
-            'prod': Configured for use in a production environment.
-            'stage': Configured for use in a development/staging environment.
-            'local': Configured for use with a local Flask server.
-            'testing': Configured for use in unit testing.
+
+            ``prod``: Configured for use in a production environment.
+
+            ``stage``: Configured for use in a development/staging environment.
+
+            ``local``: Configured for use with a local Flask server.
+
+            ``testing``: Configured for use in unit testing.
+
+            ``cli``: Configured for use in a production environment without initializing extensions. (Use for CI/CD)
         api_title: The title (name) of the API to display in the OpenAPI documentation.
         api_version: The semantic version for the OpenAPI client.
         openapi_client_name: The package name to use for generated OpenAPI clients.
