@@ -11,12 +11,11 @@ import flask
 
 # noinspection PyPackageRequirements
 import marshmallow as ma
-
+from http import HTTPStatus
 from typing import TYPE_CHECKING
 
 # noinspection PyPackageRequirements
-from werkzeug.exceptions import default_exceptions
-from flask_sqlalchemy import BaseQuery as BaseQueryOrig
+from flask_sqlalchemy.query import Query as QueryOrig
 from marshmallow_sqlalchemy import SQLAlchemyAutoSchema
 from flask_smorest import Api as ApiOrig, Blueprint as BlueprintOrig, Page
 
@@ -37,32 +36,40 @@ ISO_8601_DATETIME_FMT = "%Y-%m-%dT%H:%M:%SZ"  # This is acceptable in ISO 8601 a
 # ======================================================================================================================
 # Functions: Public
 # ======================================================================================================================
-def abort(http_status_code: int, message: Optional[str] = None) -> None:
-    """Raise a HTTPException for the given http_status_code. Attach any keyword arguments to the exception for later
+def abort(http_status: HTTPStatus, message: Optional[str] = None) -> None:
+    """Raise a HTTPException for the given ``http_status``. Attach any keyword arguments to the exception for later
     processing.
 
     Args:
-        http_status_code: Status code will be looked up in the list of exceptions and will raise that exception.
-        message: Custom message to return within the body or a default message will be returned instead.
+        http_status: A valid HTTPStatus enum which will be used for reporting the HTTP response status and code.
+        message: Custom message to return within the body or a default HTTP status message will be returned instead.
+
+    Raises:
+        werkzeug.exceptions.HTTPException: An exception containing the HTTP status code and custom message if supplied.
     """
 
-    try:
-        message = (
-            message
-            if message and http_status_code in default_exceptions.keys()
-            else default_exceptions[http_status_code].description
-        )
-    except KeyError:
-        message = f"no exception for {http_status_code}"
+    message = message if message else http_status.phrase
 
-    flask.abort(flask.make_response(flask.jsonify(message=message), http_status_code))
+    flask.abort(
+        flask.make_response(
+            flask.jsonify(
+                code=http_status.value,
+                status=http_status.name,
+                message=message,
+            ),
+            http_status,
+        )
+    )
 
 
 # ======================================================================================================================
 # Classes: Public
 # ======================================================================================================================
 class Blueprint(BlueprintOrig):
-    """Blueprint override"""
+    """
+    :class:`Blueprint <flask_smorest.Blueprint>` override example. See comments below on how to create a custom
+    converter for your schemas.
+    """
 
 
 # Define custom converter to schema function
@@ -71,7 +78,18 @@ class Blueprint(BlueprintOrig):
 
 
 class Api(ApiOrig):
-    """Api override"""
+    """
+    Extension of the :class:`flask_smorest.Api <flask_smorest.Api>` main class which provides helpers to build a
+    REST API using Flask.
+
+    Using this extension will automatically enable an "Authorize" button to the SwaggerUI docs.
+
+    Args:
+        app: Flask application
+        spec_kwargs: kwargs to pass to internal APISpec instance.
+            The ``spec_kwargs`` dictionary is passed as kwargs to the internal APISpec instance. **flask-smorest**
+            adds a few parameters to the original parameters documented in :class:`apispec.APISpec <apispec.APISpec>`
+    """
 
     def __init__(self, app: Optional[flask.Flask] = None, *, spec_kwargs: Optional[dict[str, Any]] = None):
         super().__init__(app, spec_kwargs=spec_kwargs)
@@ -81,7 +99,10 @@ class Api(ApiOrig):
 
 
 class Schema(ma.Schema):
-    """Schema override"""
+    """
+    Extend :class:`Schema <marshmallow.Schema>` to automatically exclude unknown fields and enforce ordering of
+    fields in the :swagger-ui:`SwaggerUI documentation <>`.
+    """
 
     class Meta(ma.Schema.Meta):
         unknown = ma.EXCLUDE
@@ -89,7 +110,12 @@ class Schema(ma.Schema):
 
 
 class AutoSchema(SQLAlchemyAutoSchema):
-    """SQLAlchemyAutoSchema override"""
+    """
+    Extend :class:`SQLAlchemyAutoSchema <marshmallow_sqlalchemy.SQLAlchemyAutoSchema>` to include the
+    foreign key, automatically raise an exception when unknown fields are specified, enforce ordering of fields
+    in the :swagger-ui:`SwaggerUI and enforce the use of ISO-8601 for datetime fields.
+    documentation <>`.
+    """
 
     class Meta(SQLAlchemyAutoSchema.Meta):
         include_fk = True
@@ -98,8 +124,6 @@ class AutoSchema(SQLAlchemyAutoSchema):
         datetimeformat = ISO_8601_DATETIME_FMT
 
     def update(self, obj: Any, data: Any) -> None:
-        """Update object nullifying missing data"""
-
         loadable_fields = [k for k, v in self.fields.items() if not v.dump_only]
 
         for name in loadable_fields:
@@ -112,16 +136,18 @@ class AutoSchema(SQLAlchemyAutoSchema):
 
 
 class SQLCursorPage(Page):
-    """SQL cursor pager"""
+    """:doc:`SQL cursor pager used for paginated endpoints. <flask-smorest:pagination>`"""
 
-    # https://flask-smorest.readthedocs.io/en/latest/pagination.html
     @property
     def item_count(self) -> int:
         return self.collection.count()  # type: ignore
 
 
-class BaseQuery(BaseQueryOrig):  # type: ignore
-    """Enable customized REST JSON error messages for 'get_or_404' and 'first_or_404' methods."""
+class Query(QueryOrig):  # type: ignore
+    """
+    Enable customized REST JSON error messages for 'get_or_404' and 'first_or_404' methods for
+    :class:`Query <flask_sqlalchemy.query.Query>`.
+    """
 
     def get_or_404(self, ident: object, description: Optional[str] = None) -> Any:
         """Like `get` but aborts with 404 if not found instead of returning ``None``.
@@ -134,7 +160,7 @@ class BaseQuery(BaseQueryOrig):  # type: ignore
 
         rv = self.get(ident)
         if rv is None:
-            abort(404, message=description)
+            abort(HTTPStatus(404), message=description)
         return rv
 
     def first_or_404(self, description: Optional[str] = None) -> Any:
@@ -146,5 +172,5 @@ class BaseQuery(BaseQueryOrig):  # type: ignore
 
         rv = self.first()
         if rv is None:
-            abort(404, message=description)
+            abort(HTTPStatus(404), message=description)
         return rv
