@@ -7,6 +7,7 @@ from __future__ import annotations
 import pytest
 from flask import Flask
 from typing import TYPE_CHECKING
+from collections import OrderedDict
 from flask_ligand.default_settings import TestingConfig as ConfigForTesting  # Renamed because of pytest warning
 
 # noinspection PyProtectedMember
@@ -30,6 +31,21 @@ if TYPE_CHECKING:
     from pytest_flask_ligand import FlaskLigandTestHelpers
 
 
+# ======================================================================================================================
+# Globals
+# ======================================================================================================================
+MOCK_REQUIRED_ENV_VARS = OrderedDict(
+    {
+        "SERVICE_PUBLIC_URL": "http://service.public.url",
+        "SERVICE_PRIVATE_URL": "http://service.private.url",
+        "ALLOWED_ROLES": "user,admin",
+        "OIDC_DISCOVERY_URL": "http://oidc.discovery.url/.well-known/openid-configuration",
+        "SQLALCHEMY_DATABASE_URI": "sqlite:///:memory:",
+        "OPENAPI_GEN_SERVER_URL": "http://openapi.gen.server.url",
+    }
+)
+
+
 # ======================================================================================================================
 # Fixtures
 # ======================================================================================================================
@@ -47,59 +63,50 @@ def unconfigured_flask_app() -> Flask:
     return Flask("TEST_APP")
 
 
+@pytest.fixture(scope="function")
+def mocked_req_env_vars(mocker: MockerFixture) -> OrderedDict[str, Any]:
+    """Mock the environment variables for required settings."""
+
+    return mocker.patch.dict("os.environ", MOCK_REQUIRED_ENV_VARS)
+
+
 # ======================================================================================================================
 # Test Suites
 # ======================================================================================================================
 class TestDefaultConfig(object):
     """Test cases for the '_DefaultConfig' class."""
 
-    def test_happy_path(self, default_config_args: dict[str, Any], mocker: MockerFixture) -> None:
+    def test_happy_path(self, default_config_args: dict[str, Any], mocked_req_env_vars: OrderedDict[str, Any]) -> None:
         """Verify that the correct default config settings are created for all inherited environments."""
 
-        mocked_env = {
-            "SERVICE_PUBLIC_URL": "http://service.public.url",
-            "SERVICE_PRIVATE_URL": "http://service.private.url",
-            "ALLOWED_ROLES": "user,admin",
-            "OIDC_ISSUER_URL": "http://oidc.issuer.url",
-            "OIDC_REALM": "oidc_realm",
-            "SQLALCHEMY_DATABASE_URI": "sqlite:///:memory:",
-            "OPENAPI_GEN_SERVER_URL": "http://openapi.gen.server.url",
-        }
-
-        mocker.patch.dict("os.environ", mocked_env)
-
-        mocker.patch(
-            "os.path.dirname",
-            return_value="/fake/path",
-        )
-
         config_exp: dict[str, Any] = {
             "API_TITLE": default_config_args["api_title"],
             "API_VERSION": default_config_args["api_version"],
             "OPENAPI_CLIENT_NAME": default_config_args["openapi_client_name"],
-            "SERVICE_PUBLIC_URL": mocked_env["SERVICE_PUBLIC_URL"],
-            "SERVICE_PRIVATE_URL": mocked_env["SERVICE_PRIVATE_URL"],
-            "ALLOWED_ROLES": mocked_env["ALLOWED_ROLES"].split(","),
-            "SQLALCHEMY_DATABASE_URI": mocked_env["SQLALCHEMY_DATABASE_URI"],
+            "SERVICE_PUBLIC_URL": mocked_req_env_vars["SERVICE_PUBLIC_URL"],
+            "SERVICE_PRIVATE_URL": mocked_req_env_vars["SERVICE_PRIVATE_URL"],
+            "ALLOWED_ROLES": mocked_req_env_vars["ALLOWED_ROLES"].split(","),
+            "SQLALCHEMY_DATABASE_URI": mocked_req_env_vars["SQLALCHEMY_DATABASE_URI"],
             "SQLALCHEMY_TRACK_MODIFICATIONS": False,
             "DB_AUTO_UPGRADE": False,
             "DB_MIGRATION_DIR": "migrations",
             "JSON_SORT_KEYS": False,
-            "OIDC_ISSUER_URL": mocked_env["OIDC_ISSUER_URL"],
-            "OIDC_REALM": mocked_env["OIDC_REALM"],
+            "OIDC_DISCOVERY_URL": mocked_req_env_vars["OIDC_DISCOVERY_URL"],
             "VERIFY_SSL_CERT": True,
             "JWT_TOKEN_LOCATION": "headers",
             "JWT_HEADER_NAME": "Authorization",
             "JWT_HEADER_TYPE": "Bearer",
             "JWT_ERROR_MESSAGE_KEY": "message",
             "JWT_PUBLIC_KEY": "",
-            "OPENAPI_GEN_SERVER_URL": mocked_env["OPENAPI_GEN_SERVER_URL"],
+            "OPENAPI_GEN_SERVER_URL": mocked_req_env_vars["OPENAPI_GEN_SERVER_URL"],
             "OPENAPI_VERSION": "3.0.3",
             "OPENAPI_URL_PREFIX": "/",
             "OPENAPI_JSON_PATH": "/openapi/api-spec.json",
             "OPENAPI_SWAGGER_UI_PATH": "/apidocs",
             "OPENAPI_SWAGGER_UI_URL": "https://cdn.jsdelivr.net/npm/swagger-ui-dist/",
-            "API_SPEC_OPTIONS": {"servers": [{"url": mocked_env["SERVICE_PUBLIC_URL"], "description": "Public URL"}]},
+            "API_SPEC_OPTIONS": {
+                "servers": [{"url": mocked_req_env_vars["SERVICE_PUBLIC_URL"], "description": "Public URL"}]
+            },
         }
 
         config_actual = _DefaultConfig(
@@ -111,7 +118,12 @@ class TestDefaultConfig(object):
         # noinspection PyUnresolvedReferences
         assert config_actual == config_exp
 
-    def test_override_setting(self, default_config_args, helpers):
+    def test_override_setting(
+        self,
+        default_config_args: dict[str, Any],
+        mocked_req_env_vars: OrderedDict[str, Any],
+        helpers: FlaskLigandTestHelpers,
+    ):
         """Verify that an unprotected default setting can be overridden."""
 
         config_setting_override_exp: dict[str, Any] = {"OPENAPI_VERSION": "override_setting"}
@@ -125,7 +137,12 @@ class TestDefaultConfig(object):
 
         assert helpers.is_sub_dict(config_setting_override_exp, config_actual)
 
-    def test_additional_setting(self, default_config_args, helpers):
+    def test_additional_setting(
+        self,
+        default_config_args: dict[str, Any],
+        mocked_req_env_vars: OrderedDict[str, Any],
+        helpers: FlaskLigandTestHelpers,
+    ):
         """Verify that additional settings can be specified."""
 
         config_additional_setting_exp: dict[str, Any] = {"A_NEW_SETTING": "a new setting value"}
@@ -143,26 +160,47 @@ class TestDefaultConfig(object):
 class TestNegativeDefaultConfig(object):
     """Negative test cases for the '_DefaultConfig' class."""
 
-    def test_required_env_var_not_set(self, default_config_args):
+    @pytest.mark.parametrize(
+        "mocked_env_var_index,mocked_env_vars",
+        [
+            (0, {items[0]: items[1] for i, items in enumerate(MOCK_REQUIRED_ENV_VARS.items()) if i != 0}),
+            (1, {items[0]: items[1] for i, items in enumerate(MOCK_REQUIRED_ENV_VARS.items()) if i != 1}),
+            (2, {items[0]: items[1] for i, items in enumerate(MOCK_REQUIRED_ENV_VARS.items()) if i != 2}),
+            (3, {items[0]: items[1] for i, items in enumerate(MOCK_REQUIRED_ENV_VARS.items()) if i != 3}),
+            (4, {items[0]: items[1] for i, items in enumerate(MOCK_REQUIRED_ENV_VARS.items()) if i != 4}),
+            (5, {items[0]: items[1] for i, items in enumerate(MOCK_REQUIRED_ENV_VARS.items()) if i != 5}),
+        ],
+    )
+    def test_required_env_var_not_set(
+        self,
+        default_config_args: dict[str, Any],
+        mocker: MockerFixture,
+        mocked_env_var_index: int,
+        mocked_env_vars: OrderedDict[str, Any],
+    ):
         """Verify that unset required environment variable(s) have appropriate default values or 'None'."""
 
-        config_actual = _DefaultConfig(
-            default_config_args["api_title"],
-            default_config_args["api_version"],
-            default_config_args["openapi_client_name"],
+        mocker.patch.dict("os.environ", mocked_env_vars)
+
+        with pytest.raises(RuntimeError) as e:
+            _DefaultConfig(
+                default_config_args["api_title"],
+                default_config_args["api_version"],
+                default_config_args["openapi_client_name"],
+            )
+
+        assert (
+            str(e.value) == f"The '{list(MOCK_REQUIRED_ENV_VARS)[mocked_env_var_index]}' "
+            f"environment variable must be set when running in this Flask environment!"
         )
 
-        assert config_actual["ALLOWED_ROLES"] == [""]
-
-        for env_var in (
-            "SERVICE_PUBLIC_URL",
-            "SERVICE_PRIVATE_URL",
-            "OPENAPI_GEN_SERVER_URL",
-        ):
-            assert config_actual[env_var] is None
-
     @pytest.mark.parametrize("protected_setting", ["API_TITLE", "API_VERSION", "OPENAPI_CLIENT_NAME"])
-    def test_override_protected_setting(self, default_config_args: dict[str, Any], protected_setting: str) -> None:
+    def test_override_protected_setting(
+        self,
+        default_config_args: dict[str, Any],
+        mocked_req_env_vars: OrderedDict[str, Any],
+        protected_setting: str,
+    ) -> None:
         """Verify that attempting to override a protected setting will raise the appropriate exception."""
 
         with pytest.raises(RuntimeError) as e:
@@ -176,7 +214,11 @@ class TestNegativeDefaultConfig(object):
         # noinspection PyUnresolvedReferences
         assert str(e.value) == f"The '{protected_setting}' setting is not allowed to be overridden!"
 
-    def test_add_lowercase_setting(self, default_config_args):
+    def test_add_lowercase_setting(
+        self,
+        default_config_args: dict[str, Any],
+        mocked_req_env_vars: OrderedDict[str, Any],
+    ):
         """Verify that attempting to add an all lowercase setting will raise the appropriate exception."""
 
         setting_name_exp: dict[str, Any] = {"lower_case_setting": "is_not_allowed"}
@@ -197,11 +239,14 @@ class TestProdConfig(object):
     """Test cases for the 'ProdConfig' class."""
 
     def test_happy_path(
-        self, default_config_args: dict[str, Any], mocker: MockerFixture, helpers: FlaskLigandTestHelpers
+        self,
+        default_config_args: dict[str, Any],
+        mocker: MockerFixture,
+        helpers: FlaskLigandTestHelpers,
     ) -> None:
         """Verify that the correct config settings are created for the 'prod' environment."""
 
-        mocked_env = {"JWT_DECODE_AUDIENCE": "account"}
+        mocked_env = {"JWT_DECODE_AUDIENCE": "account", **MOCK_REQUIRED_ENV_VARS}
 
         mocker.patch.dict("os.environ", mocked_env)
 
@@ -218,7 +263,12 @@ class TestProdConfig(object):
 
         assert helpers.is_sub_dict(config_exp, config_actual)
 
-    def test_override_setting(self, default_config_args, helpers):
+    def test_override_setting(
+        self,
+        default_config_args: dict[str, Any],
+        mocked_req_env_vars: OrderedDict[str, Any],
+        helpers: FlaskLigandTestHelpers,
+    ):
         """Verify that an unprotected default setting can be overridden."""
 
         config_setting_override_exp: dict[str, Any] = {"JWT_ALGORITHM": "RS512"}
@@ -232,7 +282,12 @@ class TestProdConfig(object):
 
         assert helpers.is_sub_dict(config_setting_override_exp, config_actual)
 
-    def test_additional_setting(self, default_config_args, helpers):
+    def test_additional_setting(
+        self,
+        default_config_args: dict[str, Any],
+        mocked_req_env_vars: OrderedDict[str, Any],
+        helpers: FlaskLigandTestHelpers,
+    ):
         """Verify that additional settings can be specified."""
 
         config_additional_setting_exp: dict[str, Any] = {"A_NEW_SETTING": "a new setting value"}
@@ -250,7 +305,11 @@ class TestProdConfig(object):
 class TestNegativeProdConfig(object):
     """Negative test cases for the 'ProdConfig' class."""
 
-    def test_required_env_var_not_set(self, default_config_args):
+    def test_required_env_var_not_set(
+        self,
+        default_config_args: dict[str, Any],
+        mocked_req_env_vars: OrderedDict[str, Any],
+    ):
         """Verify that unset required environment variable(s) have no default value."""
 
         config_actual = ProdConfig(
@@ -265,7 +324,12 @@ class TestNegativeProdConfig(object):
 class TestStagingConfig(object):
     """Test cases for the 'StagingConfig' class."""
 
-    def test_happy_path(self, default_config_args, helpers):
+    def test_happy_path(
+        self,
+        default_config_args: dict[str, Any],
+        mocked_req_env_vars: OrderedDict[str, Any],
+        helpers: FlaskLigandTestHelpers,
+    ):
         """Verify that the correct config settings are created for the 'dev' environment."""
 
         config_exp: dict[str, Any] = {"VERIFY_SSL_CERT": False}
@@ -278,7 +342,12 @@ class TestStagingConfig(object):
 
         assert helpers.is_sub_dict(config_exp, config_actual)
 
-    def test_override_setting(self, default_config_args, helpers):
+    def test_override_setting(
+        self,
+        default_config_args: dict[str, Any],
+        mocked_req_env_vars: OrderedDict[str, Any],
+        helpers: FlaskLigandTestHelpers,
+    ):
         """Verify that an unprotected default setting can be overridden."""
 
         config_setting_override_exp: dict[str, Any] = {"VERIFY_SSL_CERT": True}
@@ -292,7 +361,12 @@ class TestStagingConfig(object):
 
         assert helpers.is_sub_dict(config_setting_override_exp, config_actual)
 
-    def test_additional_setting(self, default_config_args, helpers):
+    def test_additional_setting(
+        self,
+        default_config_args: dict[str, Any],
+        mocked_req_env_vars: OrderedDict[str, Any],
+        helpers: FlaskLigandTestHelpers,
+    ):
         """Verify that additional settings can be specified."""
 
         config_additional_setting_exp: dict[str, Any] = {"A_NEW_SETTING": "a new setting value"}
@@ -310,14 +384,27 @@ class TestStagingConfig(object):
 class TestFlaskLocalConfig(object):
     """Test cases for the 'FlaskLocalConfig' class."""
 
-    def test_happy_path(self, default_config_args: dict[str, Any], helpers: FlaskLigandTestHelpers) -> None:
+    def test_happy_path(
+        self,
+        default_config_args: dict[str, Any],
+        mocker: MockerFixture,
+        helpers: FlaskLigandTestHelpers,
+    ) -> None:
         """Verify that the correct config settings are created for the 'local' environment."""
 
+        mocked_env = {
+            "OIDC_DISCOVERY_URL": MOCK_REQUIRED_ENV_VARS["OIDC_DISCOVERY_URL"],
+        }
+
+        mocker.patch.dict("os.environ", mocked_env)
+
         # noinspection HttpUrlsUsage
         config_exp: dict[str, Any] = {
             "SERVICE_PUBLIC_URL": "http://localhost:5000",
             "SERVICE_PRIVATE_URL": "http://localhost:5000",
             "ALLOWED_ROLES": ["user", "admin"],
+            "OIDC_DISCOVERY_URL": MOCK_REQUIRED_ENV_VARS["OIDC_DISCOVERY_URL"],
+            "VERIFY_SSL_CERT": False,
             "SQLALCHEMY_DATABASE_URI": "sqlite:///:memory:",
             "OPENAPI_GEN_SERVER_URL": "http://api.openapi-generator.tech",
             "API_SPEC_OPTIONS": {"servers": [{"url": "http://localhost:5000", "description": "Public URL"}]},
@@ -331,7 +418,12 @@ class TestFlaskLocalConfig(object):
 
         assert helpers.is_sub_dict(config_exp, config_actual)
 
-    def test_override_setting(self, default_config_args, helpers):
+    def test_override_setting(
+        self,
+        default_config_args: dict[str, Any],
+        mocked_req_env_vars: OrderedDict[str, Any],
+        helpers: FlaskLigandTestHelpers,
+    ):
         """Verify that an unprotected default setting can be overridden."""
 
         config_setting_override_exp: dict[str, Any] = {"API_SPEC_OPTIONS": "something_different"}
@@ -345,7 +437,12 @@ class TestFlaskLocalConfig(object):
 
         assert helpers.is_sub_dict(config_setting_override_exp, config_actual)
 
-    def test_additional_setting(self, default_config_args, helpers):
+    def test_additional_setting(
+        self,
+        default_config_args: dict[str, Any],
+        mocked_req_env_vars: OrderedDict[str, Any],
+        helpers: FlaskLigandTestHelpers,
+    ):
         """Verify that additional settings can be specified."""
 
         config_additional_setting_exp: dict[str, Any] = {"A_NEW_SETTING": "a new setting value"}
@@ -370,8 +467,7 @@ class TestTestingConfig(object):
             "SERVICE_PUBLIC_URL": "http://public.url",
             "SERVICE_PRIVATE_URL": "http://private.url",
             "ALLOWED_ROLES": ["user", "admin"],
-            "OIDC_ISSUER_URL": "TESTING",
-            "OIDC_REALM": "TESTING",
+            "OIDC_DISCOVERY_URL": "TESTING",
             "VERIFY_SSL_CERT": False,
             "JWT_ACCESS_TOKEN_EXPIRES": 300,
             "JWT_SECRET_KEY": "super-duper-secret",
@@ -388,7 +484,7 @@ class TestTestingConfig(object):
 
         assert helpers.is_sub_dict(config_exp, config_actual)
 
-    def test_override_setting(self, default_config_args, helpers):
+    def test_override_setting(self, default_config_args: dict[str, Any], helpers: FlaskLigandTestHelpers):
         """Verify that an unprotected default setting can be overridden."""
 
         config_setting_override_exp: dict[str, Any] = {"JWT_ACCESS_TOKEN_EXPIRES": 200}
@@ -402,7 +498,7 @@ class TestTestingConfig(object):
 
         assert helpers.is_sub_dict(config_setting_override_exp, config_actual)
 
-    def test_additional_setting(self, default_config_args, helpers):
+    def test_additional_setting(self, default_config_args: dict[str, Any], helpers: FlaskLigandTestHelpers):
         """Verify that additional settings can be specified."""
 
         config_additional_setting_exp: dict[str, Any] = {"A_NEW_SETTING": "a new setting value"}
@@ -423,7 +519,7 @@ class TestFlaskEnvironmentConfigurator(object):
     def test_environment_count(self):
         """Verify that the expected number of environments exist. (No more, no less)"""
 
-        assert len(ENVIRONMENTS) == 4
+        assert len(ENVIRONMENTS) == 5
 
     @pytest.mark.parametrize(
         "env_name,env_config_class",
@@ -451,7 +547,7 @@ class TestFlaskEnvironmentConfigurator(object):
 class TestNegativeFlaskEnvironmentConfigurator(object):
     """Negative test cases for the 'flask_environment_configurator' function."""
 
-    def test_specify_invalid_environment_name(self, default_config_args, unconfigured_flask_app):
+    def test_specify_invalid_environment_name(self, default_config_args: dict[str, Any], unconfigured_flask_app):
         """Verify that specifying an invalid environment name will raise the expected exception."""
 
         invalid_env_name = "bad!"
